---
title: llarp/rpc/endpoints.hpp

---

# llarp/rpc/endpoints.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::rpc](Namespaces/namespacellarp_1_1rpc.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| struct | **[llarp::rpc::Endpoint](Classes/structllarp_1_1rpc_1_1Endpoint.md)**  |
| struct | **[llarp::rpc::FastEndpoint](Classes/structllarp_1_1rpc_1_1FastEndpoint.md)**  |
| struct | **[llarp::rpc::HaltEndpoint](Classes/structllarp_1_1rpc_1_1HaltEndpoint.md)**  |
| struct | **[llarp::rpc::GetVersionEndpoint](Classes/structllarp_1_1rpc_1_1GetVersionEndpoint.md)**  |
| struct | **[llarp::rpc::LogsEndpoint](Classes/structllarp_1_1rpc_1_1LogsEndpoint.md)**  |
| struct | **[llarp::rpc::SlowEndpoint](Classes/structllarp_1_1rpc_1_1SlowEndpoint.md)**  |
| struct | **[llarp::rpc::GetStatusEndpoint](Classes/structllarp_1_1rpc_1_1GetStatusEndpoint.md)**  |




## Source code

```cpp
#pragma once

#include <string_view>
#include <llarp/config/config.hpp>
#include <oxenmq/oxenmq.h>
#include <oxenmq/address.h>
#include <oxen/log/omq_logger.hpp>


namespace llarp
{
  struct AbstractRouter;
} 


namespace llarp::rpc
{
  // base struct to be inherited
  struct Endpoint {
    Endpoint() {};
    Endpoint(std::string _str) : response(_str) {};
    Endpoint(nlohmann::json _json) : response(_json) {};
    ~Endpoint() = default;

    std::variant<std::string, nlohmann::json> response;

  };

  // these endpoints use the send_reply() functionality to send message in the current cycle
  struct FastEndpoint : virtual Endpoint { 

    using Endpoint::Endpoint;
    
    virtual void SendImmediate() {};
  };

  struct HaltEndpoint : virtual FastEndpoint { 

    using FastEndpoint::FastEndpoint;
    
    void SendImmediate() override {

    };
  };

  struct GetVersionEndpoint : virtual FastEndpoint { 

    using FastEndpoint::FastEndpoint;
    
    void SendImmediate() override {

    };
  };

  struct LogsEndpoint : virtual FastEndpoint { 
    
    void SendImmediate() override {

    };
  };


  // these endpoints use the reply() functionality to send a delayed message in the next cycle
  struct SlowEndpoint : virtual public Endpoint { 

    using Endpoint::Endpoint;

    virtual void SendDelayed() {};
  };

  struct GetStatusEndpoint : virtual public SlowEndpoint { 

    GetStatusEndpoint() : verbose(false) {};
    GetStatusEndpoint(std::string _str) : verbose(false) {
      response = _str;
    };
    GetStatusEndpoint(nlohmann::json _json) : verbose(false) {
      response = _json;
    };
    
    ~GetStatusEndpoint() = default;

    bool verbose;

    void SendDelayed() override {

    };
  };

  

}  // namespace llarp::rpc


/*
    Fast Endpoints (send_reply):
      - halt
      - version
      - logs

    Slow Endpoints (reply):
      - get_status
      - status
      - quic_connect
      - quic_listener
      - lookup_snode
      - endpoint
      - exit
      - dns_query
      - config

*/
```


-------------------------------

Updated on 2023-01-12 at 15:42:47 +0000
