---
title: llarp/rpc/rpc_server.hpp

---

# llarp/rpc/rpc_server.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::rpc](Namespaces/namespacellarp_1_1rpc.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| struct | **[llarp::rpc::MessageHandler](Classes/structllarp_1_1rpc_1_1MessageHandler.md)**  |
| struct | **[llarp::rpc::RPCServer](Classes/structllarp_1_1rpc_1_1RPCServer.md)**  |




## Source code

```cpp
#pragma once

#include <string_view>
#include <llarp/rpc/endpoints.hpp>
#include <llarp/config/config.hpp>
#include <oxenmq/oxenmq.h>
#include <oxenmq/address.h>
#include <oxen/log/omq_logger.hpp>


namespace llarp
{
  struct AbstractRouter;
} 


namespace llarp::rpc
{
  using LMQ_ptr = std::shared_ptr<oxenmq::OxenMQ>;


  struct MessageHandler
  {
    // constructors + destructor
    explicit MessageHandler(AbstractRouter&);

    explicit MessageHandler(AbstractRouter& _r) : m_Router(_r) {};
    
    ~MessageHandler() = default;

    void 
    SendImmediateResponse(oxenmq::Message& msg);
    void 
    SendDelayedResponse(oxenmq::Message& msg);

    void
    SendImmediateError(oxenmq::Message& msg);

    // member attributes
    AbstractRouter& const m_Router;

    std::unique_ptr<Endpoint> endpoint;
  };

  struct RPCServer
  {
    explicit RPCServer(LMQ_ptr, AbstractRouter&);
    ~RPCServer() = default;

    template <typename Result_t>
    std::string
    CreateJSONResponse(Result_t result) 
        { return nlohmann::json{{"error", nullptr},{"result"}, result}.dump(); }

    std::string
    CreateJSONError(std::string_view msg) 
        { return nlohmann::json{{"error", msg}}.dump(); }

    void
    AddCategories();

  private:

    LMQ_ptr m_LMQ;
    AbstractRouter& const m_Router;
    oxen::log::PubsubLogger log_subs;
    std::unique_ptr<MessageHandler> handler;

  };

}  // namespace llarp::rpc
```


-------------------------------

Updated on 2023-01-12 at 15:42:47 +0000
